@@ -52,6 +52,9 @@ class AccelEntry( gobject.GObject ):
 		return self.entry.get_text()
 
 	def set_accelerator_name(self, value):
+		if value == None:
+			value = ""
+			
 		(keyval, mods) = gtk.accelerator_parse(value)
 		if gtk.accelerator_valid(keyval, mods):
 			self.entry.set_text(value)
@@ -100,8 +103,12 @@ class AccelEntry( gobject.GObject ):
 		edited = False
 		
 		keymap = gtk.gdk.keymap_get_default()
-		(keyval, egroup, level, consumed_modifiers) = keymap.translate_keyboard_state(event.hardware_keycode, event.state, event.group)
-
+		translation = keymap.translate_keyboard_state(event.hardware_keycode, event.state, event.group)
+		if translation == None:
+			self.__revert()
+			return
+			
+		(keyval, egroup, level, consumed_modifiers) = translation
 		upper = event.keyval
 		accel_keyval = gtk.gdk.keyval_to_lower(upper)
 
@@ -114,12 +121,12 @@ class AccelEntry( gobject.GObject ):
 		accel_mods = event.state & gtk.gdk.MODIFIER_MASK & ~(consumed_modifiers | ignored_modifiers)
 		
 		if accel_mods == 0 and accel_keyval == gtk.keysyms.Escape:
-			self.__cancel()
-			return # cancel
+			self.__revert()
+			return
 		
 		if not gtk.accelerator_valid(accel_keyval, accel_mods):
 			self.__cancel()
-			return # cancel
+			return
 
 		accel_name = gtk.accelerator_name(accel_keyval, accel_mods)
 		self.set_accelerator(accel_keyval, event.hardware_keycode, accel_mods)
@@ -129,12 +136,13 @@ class AccelEntry( gobject.GObject ):
 
 	def __on_focus_out_event(self, entry, event):
 		if self.__old_value != None:
-			self.__cancel()
+			self.__revert()
 
 	def __cancel(self):
+		self.set_accelerator_name("")
+	
+	def __revert(self):
 		self.set_accelerator_name(self.__old_value)
-		return
-		
 
 class DeskbarPreferencesUI:
 	def __init__(self, applet, module_loader, module_list):
@@ -171,6 +179,7 @@ class DeskbarPreferencesUI:
 		container.add(self.moduleview)
 
 		self.default_info = self.glade.get_widget("default_info")
+		self.width_units = self.glade.get_widget("width_units")
 
 		self.other_info = gtk.HBox(spacing=6)
 		info_image = gtk.image_new_from_stock(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_BUTTON)
@@ -249,10 +258,10 @@ class DeskbarPreferencesUI:
 	def set_width_settings_sensitive(self, sensitive):
 		if sensitive and not self.expand:
 			self.width_spin.set_sensitive(True)
-			self.glade.get_widget("width_units").set_sensitive(True)
+			self.width_units.set_sensitive(True)
 		else:
 			self.width_spin.set_sensitive(False)
-			self.glade.get_widget("width_units").set_sensitive(False)
+			self.width_units.set_sensitive(False)
 			
 		self.use_all_width_radio.set_sensitive(sensitive)
 		self.fixed_width_radio.set_sensitive(sensitive)
